const { app, BrowserWindow } = require('electron');
const settings = require("./settings.json");
const isDebug = settings.debug === true;

// Handle creating/removing shortcuts on Windows when installing/uninstalling.
if (require('electron-squirrel-startup')) { // eslint-disable-line global-require
  app.quit();
}

// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
let mainWindow = null;

const createWindow = () => {
  // Create the browser window.

  let options = {
    webPreferences: {
      nodeIntegration: true,
    },
    width: settings.appWidth,
    height: settings.appHeight,
    frame: false,
    titleBarStyle: "hidden",
    backgroundColor: "#262626",
    fullscreenable: false,
    title: settings.productName || "Fuse Fonts Installer",
  };

  if (isDebug) {
    options = Object.assign(options, {
      width: 1000,
      height: 700,
      'min-width': 1000,
      'min-height': 700,
      'max-width': 1920,
      'max-height': 1920,
    });
  }

  mainWindow = new BrowserWindow(options);

  // and load the index.html of the app.
  mainWindow.loadURL(`file://${__dirname}/index.html`);

  // Open the DevTools.
  if (isDebug) {
    mainWindow.webContents.openDevTools();
  }

  // Emitted when the window is closed.
  mainWindow.on('closed', () => {
    // Dereference the window object, usually you would store windows
    // in an array if your app supports multi windows, this is the time
    // when you should delete the corresponding element.
    mainWindow = null;
  });
};

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.on('ready', createWindow);

// Quit when all windows are closed.
app.on('window-all-closed', () => {
  // On OS X it is common for applications and their menu bar
  // to stay active until the user quits explicitly with Cmd + Q
  app.quit();
});

app.on('activate', () => {
  // On OS X it's common to re-create a window in the app when the
  // dock icon is clicked and there are no other windows open.
  if (mainWindow === null) {
    createWindow();
  }
});

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and import them here.
